package com.god.data.common.domain;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;

/**
 * 车辆报文接收对象
 * @Author fst
 * @date 2023/11/23 14:33
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class CarMessage {
    /**
     * 车辆VIN
     */
    private String vin;

    /**
     * 时间戳
     */
    private Long timeString;

    /**
     * 经度
     */
    private BigDecimal longitude;

    /**
     * 纬度
     */
    private BigDecimal latitude;

    /**
     * 速度 单位：KM/H
     */
    private BigDecimal speed;

    /**
     * 总里程
     */
    private BigDecimal sumMileage;

    /**
     * 总电压
     */
    private BigDecimal sumVoltage;

    /**
     * 总电流
     */
    private BigDecimal sumElectricity;

    /**
     * 绝缘电阻
     */
    private BigDecimal sumResistance;

    /**
     * 车辆档位
     */
    private String gear;

    /**
     * 加速踏板行程值
     */
    private BigDecimal acceleratorPedal;

    /**
     *制动踏板行程值
     */
    private BigDecimal brakePedal;

    /**
     * Specific fuel consumption 燃料消耗率
     */
    private BigDecimal specificFuelConsumption;

    /**
     * 电池控制器温度
     */
    private BigDecimal motorControllerTemperature;

    /**
     * 电机转速
     */
    private Long motorSpeed;

    /**
     * 电机转矩
     */
    private Long motorTorque;

    /**
     * 电机温度
     */
    private BigDecimal motorTemperature;

    /**
     * 电机电业
     */
    private BigDecimal motorTage;

    /**
     * 电机电流
     */
    private BigDecimal motorCurrent;

    /**
     * 动力电池剩余电流SOC
     */
    private BigDecimal remainingBattery;

    /**
     * 当前状态允许的最大反馈功率
     */
    private BigDecimal maximumFeedbackPower;

    /**
     * 当前状态允许最大放电功率
     */
    private BigDecimal maximumDischargePower;

    /**
     * BMS自检计数器
     */
    private Integer selfCheckCounter;

    /**
     * 动力电池充放电电流
     */
    private BigDecimal totalBatteryCurrent;

    /**
     * 动力电池负载端总电压V3
     */
    private BigDecimal totalBatteryVoltage;

    /**
     * 单次电池最大电压
     */
    private BigDecimal singleBatteryMaxVoltage;

    /**
     * 单体电池最低电压
     */
    private BigDecimal singleBatteryMinVoltage;

    /**
     * 单体电池最高温度
     */
    private BigDecimal singleBatteryMaxTemperature;

    /**
     * 单体电池最低温度
     */
    private BigDecimal singleBatteryMinTemperature;

    /**
     * 动力电池可用容量
     */
    private BigDecimal availableBatteryCapacity;

    /**
     * 车辆状态
     */
    private Integer vehicleStatus;

    /**
     * 充电状态
     */
    private Integer chargingStatus;

    /**
     * 运行状态
     */
    private Integer operatingStatus;

    /**
     * SOC
     */
    private Integer socStatus;

    /**
     * 可充电储能装置工作状态
     */
    private Integer chargingEnergyStorageStatus;

    /**
     * 驱动电池状态
     */
    private Integer driveMotorStatus;

    /**
     * 定位是否有效
     */
    private Integer positionStatus;

    /**
     * EAS状态
     */
    private Integer easStatus;

    /**
     * PTC状态
     */
    private Integer ptcStatus;

    /**
     * EPS状态
     */
    private Integer epsStatus;

    /**
     * ABS状态
     */
    private Integer absStatus;

    /**
     * MCU状态
     */
    private Integer mcuStatus;

    /**
     * 动力电池加热状态
     */
    private Integer heatingStatus;

    /**
     * 动力电池当前状态
     */
    private Integer batteryStatus;


    /**
     * 动力电池保温状态
     */
    private Integer batteryInsulationStatus;

    /**
     * DCDC状态
     */
    private Integer dcdcStatus;

    /**
     * CHG状态
     */
    private Integer chgStatus;

}
