package com.god.data.service;

import com.god.common.core.utils.SpringUtils;
import com.god.common.redis.service.RedisService;
import com.god.data.common.domain.CarMessage;
import com.god.data.service.impl.ElectronicFenceEvent;
import com.god.data.utils.AnalyzeUtils;
import lombok.extern.log4j.Log4j2;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.common.TopicPartition;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.time.Duration;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;


/**
 * 获取kafka数据进行解析，并执行事件
 * @author fst
 * @Date 2023-11-27 下午 20:02
 */
@Log4j2
@Component
public class ParseDataService {
    @Autowired
    private RedisService redisService;

    @Autowired
    private KafkaConsumer<String, String> consumer;



    @PostConstruct
    public void start(){

        new Thread(() -> {
            consumer.subscribe(Arrays.asList("test"));
            log.info("kafka数据解析服务启动");
            while (true){
                ConsumerRecords<String, String> records = null;
                try {
                    //死循环拉取kafka数据
                    records = consumer.poll(Duration.ofMillis(1000));
                    for (ConsumerRecord<String, String> record : records) {
                        System.out.println(record.value());
                        //把报文解析成对象
                        CarMessage carMessage = AnalyzeUtils.parseVehicleData(record.value());
                        //根据对象车辆vin获取事件集合，从redis中获取
                        List<String> eventList = redisService.getCacheList("event" + carMessage.getVin());
                        //执行事件
                        if(eventList!= null && !eventList.isEmpty()){
                            for (String event : eventList) {
                                EventService eventService = SpringUtils.getBean(event);
                                eventService.execute(carMessage);
                            }
                        }
//                        System.out.println("======="+carMessage+"====================");

                        System.out.println(record.offset() +" - "+ record.key() +" - "+ record.value());
                    }
                }catch (Exception e){
                    log.info("records： {}", records);
                    log.error(e);
                }
            }
        }).start();
    }

}
