package com.god.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.god.common.redis.service.RedisService;
import com.god.data.common.domain.CarMessage;
import com.god.data.common.domain.ElePoint;
import com.god.data.common.domain.Point;
import com.god.data.service.EventService;
import com.god.data.utils.GeofencingUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * 电子围栏数据解析事件
 * @Author fst
 * @date 2023/11/27 20:43
 */
@Service(value = "Fence")
@Log4j2
public class ElectronicFenceEvent implements EventService {

    @Autowired
    private RedisService redisService;

    @Autowired
    private RabbitTemplate rabbitTemplate;


    @Override
    public void insert() {

    }
    @Override
    public void execute(CarMessage carMessage) {
        log.info("电子围栏数据解析事件执行");
        //从redis中获取当前车辆的电子围栏数据
        List<ElePoint> list = redisService.getCacheList("Fence" + carMessage.getVin());
        //根据当前经纬度和电子围栏数据进行判断，调用算法工具类
        for (ElePoint elePoint : list) {
            //获取电子围栏数据
            String s = elePoint.getFenceLocation();
            String[] split = s.split(";");
            //转换为字符串集合，集合中字符串是 经度，纬度
            List<String> strList = Arrays.asList(split);
            //把字符串集合转换为Point集合，point存放经纬度
            List<Point> points = strList.stream()
                    .map(str -> {
                        String[] split1 = str.split(",");
                        return new Point(Double.parseDouble(split1[0]), Double.parseDouble(split1[1]));
                    }).collect(Collectors.toList());
            //获取经纬度
            Point point = new Point();
            //把当前车辆的经纬度赋值给point对象
            point.setLng(carMessage.getLongitude().doubleValue());
            point.setLat(carMessage.getLatitude().doubleValue());
            //判断车辆当前是否在点赞围栏中
            boolean inPolygon = GeofencingUtils.isInPolygon(point, points);
            //判断当前车辆是驶入/驶出围栏
            if (elePoint.getDriveStatus().equals(1)){
                //如果不在围栏范围内则，触发驶出电子围栏事件 ，存入rabbitmq中
                if (inPolygon){
                    rabbitTemplate.convertAndSend("OUT_FENCE", JSON.toJSON(elePoint), message -> {
                        message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                        return message;
                    });
                }
            }
            if (elePoint.getDriveStatus().equals(2)){
                //如果不在围栏范围内则，触发驶入电子围栏事件 ，存入rabbitmq中
                if (!inPolygon){
                    rabbitTemplate.convertAndSend("IN_FENCE", JSON.toJSON(elePoint), message -> {
                        message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                        return message;
                    });
                }
            }
        }
    }

    @Override
    public void remove(String event) {

    }
}
